# Simple components

We start out with the components that are relatively straight forward. There is no recurring option here.

::: ical_library.ical_components.VFreeBusy

::: ical_library.ical_components.VAlarm
